/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 * 
 * This file is part of SDL'd.
 * 
 * SDL'd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * SDL'd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SDL'd; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// This class is a converter, so naturally it resides in the convert package.
package convert;

// Import schtuph.
import kirk.io.sdl.*;
import java.io.IOException;

/**
 * <p>This class converts an ESDL file into an SDL file.</p>
 * 
 * <p>Usage:</p>
 * 
 * <p><code>ESDLToSDLConverter filename.esdl filename.sdl</code></p>
 * 
 * <p>or</p>
 * 
 * <p><code>ESDLToSDLConverter filename.esdl</code></p>
 * 
 * <p>if you want the filename to remain the same (only with a .sdl extension).</p>
 * 
 * @author Berend "Kirk" Wouda
 * @version 1.01
 * @since 1.00
 */
public class ESDLToSDLConverter {
	/**
	 * The starting point of the program.
	 * 
	 * @param args The commandline paramaters.
	 */
	public static void main(String[] args) {
		// Print out that it is made by me.
		System.out.println("ESDLToSDLConverter v1.01 by Kirk");
		System.out.println();

		// Check for errors.
		try {		
			// Check which functionality is required.
			if(args.length == 2) {
				// The user wants to convert the first parameter (filename) into the
				// second parameter (filename).
				// Take the first argument and use it as a filename for reading.
				SDLDocument doc = ESDLReader.readESDLFile(args[0]);

				// Take the second argument and use it as a filename for writing.
				SDLWriter.writeSDLFile(doc, args[1]);
				
				// Print out a message.
				System.out.println(args[0] + " succesfully converted into " + args[1] + ".");
			}
			else if(args.length == 1) {
				// The user wants to convert the first parameter (filename) into a file
				// with the first parameter with .esdl as extension as name.
				// Retrieve the filename from the first parameter.
				String filename1 = args[0];

				// Read the ESDL document from the filename.
				SDLDocument doc = ESDLReader.readESDLFile(filename1);
				
				// Strip the extension from the filename1 and store that in
				// filename2.
				int dotindex = filename1.lastIndexOf('.');
				String filename2 = filename1.substring(0, dotindex - 1);
				
				// Add .sdl as extension.
				filename2 += ".sdl";
				
				// Write the ESDLfile.
				SDLWriter.writeSDLFile(doc, filename2);
				
				// Print out a message.
				System.out.println(filename1 + " succesfully converted into " + filename2 + ".");
			}
			else {
				// The user wants info.
				System.out.println("  Usage:");
				System.out.println("    ESDLToSDLConverter filename1 filename2		- To convert filename1 (ESDL) into filename2 (SDL)");
				System.out.println("    ESDLToSDLConverter filename1				- To convert filename1 (ESDL) into filename1 (SDL, with .sdl as extension)");
			}
		}
		catch(IOException e) {
			// Alert the user.
			System.out.println("An error occured while trying to read the file: " + e.getMessage());
		}
		catch(ESDLReadException e) {
			// Alert the user.
			System.out.println("An error occured while reading the ESDL structure: " + e.getMessage());
		}
		catch(SDLWriteException e) {
			// Alert the user.
			System.out.println("An error occured while writing the SDL structure: " + e.getMessage());
		}
	}
}