/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 * 
 * This file is part of SDL'd.
 * 
 * SDL'd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * SDL'd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SDL'd; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// This is a normalizer.
package normalize;

// Import schtuph.
import kirk.io.sdl.*;
import java.io.IOException;

/**
 * <p>This class normalizes ESDL files. That means, it rewrites ESDL files in a
 * neatly fashioned layout. Due to the nature of the reading and writing classes,
 * comments will not make it into the new layout.</p>
 * 
 * <p>Usage:</p>
 * 
 * <p><code>ESDLNormalizer filename.esdl filename.esdl</code></p>
 * 
 * <p>or</p>
 * 
 * <p><code>ESDLNormalizer filename.esdl</code></p>
 * 
 * <p>if you want the filename to remain the same.</p>
 *
 * @author Berend "Kirk" Wouda
 * @version 1.01
 * @since 1.00
 */
public class ESDLNormalizer {
	/**
	 * The starting point of the program.
	 *
	 * @param args The commandline parameters.
	 */
	public static void main(String[] args) {
		// Print out that it is made by me.
		System.out.println("ESDLNormalizer v1.01 by Kirk");
		System.out.println();

		// Check for errors.
		try {
			// Check which functionality is required.
			if(args.length == 2) {
				// The user wants to normalize the first parameter (filename) into
				// the second parameter (filename).
				// Take the first argument and use it as a filename for reading.
				SDLDocument doc = ESDLReader.readESDLFile(args[0]);

				// Take the second argument and use it as a filename for writing.
				ESDLWriter.writeESDLFile(doc, args[1]);

				// Print out a message.
				System.out.println(args[0] + " succesfully converted into " + args[1] + ".");
			}
			else if(args.length == 1) {
				// The user wants to convert the first parameter (filename).
				// Take the first argument and use it as a filename for reading.
				SDLDocument doc = ESDLReader.readESDLFile(args[0]);

				// Take the second argument and use it as a filename for writing.
				ESDLWriter.writeESDLFile(doc, args[0]);

				// Print out a message.
				System.out.println(args[0] + " succesfully converted into " + args[0] + ".");
			}
			else {
				// The user wants info.
				System.out.println("  Usage:");
				System.out.println("    ESDLNormalizer filename1 filename2		- To convert filename1.esdl into filename2.esdl");
				System.out.println("    ESDLNormalizer filename1				- To convert filename1.esdl into filename1.esdl");
			}
		}
		catch(IOException e) {
			// Alert the user.
			System.out.println("An error occured while trying to read the file: " + e.getMessage());
		}
		catch(ESDLReadException e) {
			// Alert the user.
			System.out.println("An error occured while reading the ESDL structure: " + e.getMessage());
		}
		catch(ESDLWriteException e) {
			// Alert the user.
			System.out.println("An error occured while writing the ESDL structure: " + e.getMessage());
		}
	}
}