/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 * 
 * This file is part of SDL'd.
 * 
 * SDL'd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * SDL'd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SDL'd; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// This class is in the test package.
package test;

// Import schtuph.
import kirk.io.sdl.*;
import java.io.IOException;

/**
 * <p>This class reads and prints out an SDL file.</p>
 * 
 * <p>Usage: <code>SDLTest filename</code></p>
 * 
 * @author Berend "Kirk" Wouda
 * @version 1.01
 * @since 1.00
 */
public class SDLTest {
	/**
	 * The start of the program.
	 * 
	 * @param args The commandline parameters.
	 */
	public static void main(String[] args) {
		// Print out that it is made by me.
		System.out.println("SDLTest v1.01 by Kirk");
		System.out.println();
		
		// Check if a file was given.
		if(args.length == 1) {
			// Catch all errors.
			try {
				// Take the first argument and use it as a filename.
				SDLDocument doc = SDLReader.readSDLFile(args[0]);
				
				// Print out the SDL structure.
				System.out.println(doc.toString());
			}
			catch(IOException e) {
				// Alert the user.
				System.out.println("An error occured while trying to read the file: " + e.getMessage());
			}
			catch(SDLReadException e) {
				// Alert the user.
				System.out.println("An error occured while interpreting the SDL structure: " + e.getMessage());
			}
		}
		else {
			// No arguments. Talk stuff.
			System.out.println("  Usage:");
			System.out.println("    SDLTest filename");
		}
	}
}